'use strict';

const https = require('https');

module.exports = {
	pagedRequest: function (initialUrl, callback, pageProcessor) {
		return https.get(initialUrl, function (res) {
            let body = '';
            res.on('error', function (err) {
                callback.call(this, err, null);
            });
            res.on('data', function (data) {
                body += data;
            });
            res.on('end', function () {
                let result = JSON.parse(body);
                if (typeof (pageProcessor) == 'function')
					result = pageProcessor(result);
				if (result.hasOwnProperty('_links')) {
					if (result._links.hasOwnProperty('next'))
						result.next = function () { this.pagedRequest(result._links.next, callback, pageProcessor); };
					if (result._links.hasOwnProperty('prev'))
						result.prev = function () { this.pagedRequest(result._links.prev, callback, pageProcessor); };
				}
                callback.call(this, null, result);
            });
        });
	}
};