'use strict';

const should = require('chai').should();
const TwitchStream = require('../lib/stream');

describe('TwitchStream', function () {
    let stream = new TwitchStream('cammymanny');

    it('has the stream API defined', function () {
        should.exist(stream);
    });

    it('has a name', function () {
        stream.should.have.property('name');
    });

    it('can load stream metadata', function (done) {
        let meta = stream.info(function (err, meta) {
            meta.name.should.equal('cammymanny');
            done();
        });
    });

    it('can load follows', function (done) {
        let follows = stream.follows(function (err, result) {
            result.should.be.a('object');
            result.should.have.property('follows');
            result.should.have.property('_links');
            result.should.have.property('_total');

            if (result.follows.length > 0) {
                result.follows[0].should.have.property('stream');
                result.follows[0].stream.should.be.instanceof(TwitchStream);
            }

            done();
        });
    });

    it('follows() provides a next() function', function (done) {
        let follows = stream.follows(function (err, result) {
            result.should.have.property('next');
            done();
        }, 5, 0);
    });
	
	it('can load videos', function (done) {
		let videos = stream.videos(function (err, result) {
            result.should.be.a('object');
            result.should.have.property('videos');
            result.should.have.property('_links');
            result.should.have.property('_total');

            done();
        });
	});
});